import { DDSLoader } from './jsm/loaders/DDSLoader.js';
import { MTLLoader } from './jsm/loaders/MTLLoader.js';
import { OBJLoader } from './jsm/loaders/OBJLoader.js';

// Let's define global variables for the height and width of the window.
var width = window.innerWidth;
var height = window.innerHeight;

// Let's define a scene, a camera and a renderer.
var scene = new THREE.Scene();
var camera = new THREE.PerspectiveCamera( 45, width / height, 0.1, 1000 );

camera.position.x = 4;
camera.position.y = 1;
camera.position.z = 5;

camera.rotation.x = 0;
camera.rotation.y = 0;
camera.rotation.z = 0;


var renderer = new THREE.WebGLRenderer();
renderer.setSize( width, height ); //Initialization of the renderer size.
renderer.setClearColor( 0x434042, 1 );
document.body.appendChild( renderer.domElement );


//Resize the renderer and the camera aspect
window.addEventListener( 'resize', function( )
{
  var width = window.innerWidth;
  var height = window.innerHeight;
  renderer.setSize( width, height ); //Refresh the rendered size when the window size is changed.
  camera.aspect = width / height;
  camera.updateProjectionMatrix( );
} );


//Screen Control
var controls = new THREE.OrbitControls( camera, renderer.domElement );

// model

var onProgress = function ( xhr ) {

	if ( xhr.lengthComputable ) {

		var percentComplete = xhr.loaded / xhr.total * 100;
		console.log( Math.round( percentComplete, 2 ) + '% downloaded' );

	}

};

var onError = function () { };

var manager = new THREE.LoadingManager();
manager.addHandler( /\.dds$/i, new DDSLoader() );

// comment in the following line and import TGALoader if your asset uses TGA textures
// manager.addHandler( /\.tga$/i, new TGALoader() );

new MTLLoader( manager )
	.setPath( 'models/' )
	.load( 'Fountain_with_heads.mtl', function ( materials ) {

		materials.preload();

		new OBJLoader( manager )
			.setMaterials( materials )
			.setPath( 'models/' )
			.load( 'Fountain_with_heads.obj', function ( object ) {

				object.position.y = -1.5;
        object.position.x = 0;
				scene.add( object );

			}, onProgress, onError );

	} );


// Floor
var floorGeometry = new THREE.BoxGeometry( 50, 0.01, 50 );
var floorMaterial = new THREE.MeshPhongMaterial( {color: 0xa6a6a6, wireframe: false, side:THREE.DoubleSide } );
var floorCube = new THREE.Mesh( floorGeometry, floorMaterial );
floorCube.position.y = -1.5;
scene.add( floorCube );

//LIGHTS
var ambientLight = new THREE.AmbientLight( 0xcccccc, 0.4 );
scene.add( ambientLight );

var pointLight = new THREE.PointLight( 0xffffff, 0.3 );
camera.add( pointLight );
scene.add( camera );

var light1 = new THREE.PointLight( 0xdb1717, 2, 50); // red point light (light color, intensity, distance until which objects are affected by light)
scene.add( light1 );

var light2 = new THREE.PointLight( 0x48d09b, 2, 50); // green point light (light color, intensity, distance until which objects are affected by light)
scene.add( light2 );

var light3 = new THREE.PointLight( 0x209cee, 2, 50); // blue point light (light color, intensity, distance until which objects are affected by light)
scene.add( light3 );

// Game logic
var update = function( )
{
  var time = Date.now( ) * 0.0005;

  light1.position.x = Math.sin( time * 0.7 ) * 30;
  light1.position.y = Math.cos( time * 0.5 ) * 40;
  light1.position.z = Math.cos( time * 0.3 ) * 30;

  light2.position.x = Math.cos( time * 0.3 ) * 30;
  light2.position.y = Math.sin( time * 0.5 ) * 40;
  light2.position.z = Math.sin( time * 0.7 ) * 30;

  light3.position.x = Math.sin( time * 0.5 ) * 30;
  light3.position.y = Math.cos( time * 0.7 ) * 40;
  light3.position.z = Math.sin( time * 0.3 ) * 30;
};

// Draw Scene
var render = function( )
{
  renderer.render( scene, camera );
};

// Run Game Loop (update, render, repeat)
var GameLoop = function( )
{
  requestAnimationFrame( GameLoop );

  update( );
  render( );
};

GameLoop( );
